pub enum Error {
OutOfRange,
InvalidHeader,
Encoding,
PeerRead(Status),
PeerWrite(Status),
IOError(Status),
RequestStreamError(Error),
PeerError(String),
InvalidState,
NoChannel,
UnimplementedMessage,
InvalidArgs,
// some variants omitted
}Expand description
The Error type of the fuchsia-audio-device
Variants
OutOfRange
The value that was received was out of range
InvalidHeader
The header was invalid when parsing a message.
Encoding
Can’t encode into a buffer
PeerRead(Status)
Encountered an IO error reading
PeerWrite(Status)
Encountered an IO error writing
IOError(Status)
Other IO Error
RequestStreamError(Error)
Encountered a FIDL error reading a request
PeerError(String)
Peer performed an disallowed action and the server will close
InvalidState
Action tried in an invalid state
NoChannel
Responder doesn’t have a channel
UnimplementedMessage
When a message hasn’t been implemented yet, the parser will return this.
InvalidArgs
An argument is invalid.